==> jacktrip_1.7.0+ds.orig.tar.xz: jacktrip-1.7.0/src/Tone.h <==
//*****************************************************************
/*
  JackTrip: A System for High-Quality Audio Network Performance
  over the Internet

  Copyright (c) 2020 Julius Smith, Juan-Pablo Caceres, Chris Chafe.
  SoundWIRE group at CCRMA, Stanford University.

  Permission is hereby granted, free of charge, to any person
  obtaining a copy of this software and associated documentation
  files (the "Software"), to deal in the Software without
  restriction, including without limitation the rights to use,
  copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the
  Software is furnished to do so, subject to the following
  conditions:

  The above copyright notice and this permission notice shall be
  included in all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
  OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
  WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
  OTHER DEALINGS IN THE SOFTWARE.
*/
//*****************************************************************

/**
 * \file Tone.h
 * \author Nelson Wang
 * \date October 2022
 * \license MIT
 */

#ifndef __TONE_H__
#define __TONE_H__

#include <QObject>
#include <iostream>
#include <vector>

#include "ProcessPlugin.h"
#include "tonedsp.h"

/** \brief The Tone plugin plays some arbitrary sample audio
 */
class Tone : public ProcessPlugin
{
    Q_OBJECT;

   public:
    /// \brief The class constructor sets the number of channels to measure
    Tone(int numchans, bool verboseFlag = false) : mNumChannels(numchans)
    {
        setVerbose(verboseFlag);
        for (int i = 0; i < mNumChannels; i++) {
            toneP.push_back(new tonedsp);
            toneUIP.push_back(new APIUI);  // #included in tonedsp.h
            toneP[i]->buildUserInterface(toneUIP[i]);
        }
    }

    /// \brief The class destructor
    virtual ~Tone()
    {
        for (int i = 0; i < mNumChannels; i++) {
            delete toneP[i];
            delete toneUIP[i];
        }
        toneP.clear();
        toneUIP.clear();
    }

    void init(int samplingRate) override;
    int getNumInputs() override { return (mNumChannels); }
    int getNumOutputs() override { return (mNumChannels); }
    void compute(int nframes, float** inputs, float** outputs) override;
    const char* getName() const override { return "Tone"; };

    void updateNumChannels(int nChansIn, int nChansOut) override;

   public slots:
    void triggerPlayback();

   private:
    std::vector<tonedsp*> toneP;
    std::vector<APIUI*> toneUIP;
    float fs;
    int mNumChannels;
};

#endif

==> jacktrip_2.5.1+ds.orig.tar.xz: jacktrip-2.5.1/src/Tone.h <==
//*****************************************************************
/*
  JackTrip: A System for High-Quality Audio Network Performance
  over the Internet

  Copyright (c) 2020 Julius Smith, Juan-Pablo Caceres, Chris Chafe.
  SoundWIRE group at CCRMA, Stanford University.

  Permission is hereby granted, free of charge, to any person
  obtaining a copy of this software and associated documentation
  files (the "Software"), to deal in the Software without
  restriction, including without limitation the rights to use,
  copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the
  Software is furnished to do so, subject to the following
  conditions:

  The above copyright notice and this permission notice shall be
  included in all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
  OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
  WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
  OTHER DEALINGS IN THE SOFTWARE.
*/
//*****************************************************************

/**
 * \file Tone.h
 * \author Nelson Wang
 * \date October 2022
 * \license MIT
 */

#ifndef __TONE_H__
#define __TONE_H__

#include <QObject>
#include <vector>

#include "ProcessPlugin.h"

/** \brief The Tone plugin plays some arbitrary sample audio
 */
class Tone : public ProcessPlugin
{
    Q_OBJECT;

   public:
    /// \brief The class constructor sets the number of channels to measure
    Tone(int numchans, bool verboseFlag = false);

    /// \brief The class destructor
    virtual ~Tone();

    void init(int samplingRate, int bufferSize) override;
    int getNumInputs() override { return (mNumChannels); }
    int getNumOutputs() override { return (mNumChannels); }
    void compute(int nframes, float** inputs, float** outputs) override;
    const char* getName() const override { return "Tone"; };

    void updateNumChannels(int nChansIn, int nChansOut) override;

   public slots:
    void triggerPlayback();

   private:
    std::vector<void*> toneP;
    std::vector<void*> toneUIP;
    float fs;
    int mNumChannels;
};

#endif
